Page 45 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 45

Home

    conspiracy wanted.
    The siege of the Bastille (July 14, 1789) was a

    brilliant coup of deception upon the part of the
    revolutionaries. After being terrorized by increasing acts
    of violence by the brigands, and the breakdown of law
    and order, the people of Paris sought to obtain arms with
    which to protect themselves. Rumors were then spread
    that the Bastille housed the needed arms; whereupon, a

    large crowd went to the Bastille seeking arms, not only
    for their own safety, but to defend the Monarchy as well.
    What they found in this "hated emblem of despotism,”
    as portrayed by revolutionary writers, were not captives
    in chains or torture-chambers, but seven prisoners living

    in relative comfort. Four of the prisoners were forgers,
    two were lunatics, and one was a man who had been

    incarcerated at the request of his own family. The King
    had already planned to tear down the ancient prison, but
    this was something his enemies could not afford him the

    honor of doing.
    An area also not overlooked by the tevolutionaries

    ew

    was the corrupting of the military, whether by bribery,
    the use of prostitutes, or outright murder. Surprisingly,
    Lafayette became a member of the Illuminati and joined
    the Revolution shortly after helping George Washington
    defeat the British. Lafayette vacillated back and forth
    between support for the Revolution and support for the
    Monarchy until he was forced to flee to the frontier

    40

    The Secret Side of History

    demands. It was not reform, but revolution that the

    where he was arrested and imprisoned by the Austrians.